@@ -32,7 +32,7 @@ namespace RTShader {
 /************************************************************************/
 /*                                                                      */
 /************************************************************************/
-String FFPLighting::Type = "FFP_Lighting";
+const String SRS_PER_VERTEX_LIGHTING = "FFP_Lighting";
 
 //-----------------------------------------------------------------------
 FFPLighting::FFPLighting()
@@ -46,7 +46,7 @@ FFPLighting::FFPLighting()
 //-----------------------------------------------------------------------
 const String& FFPLighting::getType() const
 {
-	return Type;
+	return SRS_PER_VERTEX_LIGHTING;
 }
 
 
@@ -275,8 +275,7 @@ bool FFPLighting::addFunctionInvocations(ProgramSet* programSet)
         auto psOutDiffuse = psMain->resolveOutputParameter(Parameter::SPC_COLOR_DIFFUSE);
 
         auto fstage = psMain->getStage(FFP_PS_COLOUR_BEGIN);
-        fstage.callFunction("SGX_ApplyShadowFactor_Diffuse",
-                            {In(ambient), In(psOutDiffuse), In(shadowFactor), Out(psOutDiffuse)});
+        fstage.callFunction("SGX_ApplyShadowFactor_Diffuse", {In(ambient), In(shadowFactor), InOut(psOutDiffuse)});
         if (mSpecularEnable)
         {
             auto psSpecular = psMain->getInputParameter(Parameter::SPC_COLOR_SPECULAR);
@@ -320,7 +319,7 @@ void FFPLighting::addGlobalIlluminationInvocation(const FunctionStageRef& stage)
 
 		if (mTrackVertexColourType & TVC_EMISSIVE)
 		{
-            stage.add(mInDiffuse, mOutDiffuse, mOutDiffuse);
+			stage.add(In(mInDiffuse).xyz(), In(mOutDiffuse).xyz(), Out(mOutDiffuse).xyz());
 		}
 		else
 		{
@@ -499,7 +498,7 @@ bool FFPLighting::setParameter(const String& name, const String& value)
 //-----------------------------------------------------------------------
 void FFPLighting::setLightCount(const Vector3i& lightCount)
 {
-	for (int type=0; type < 3; ++type)
+	for (int type : {1, 0, 2}) // directional first
 	{
 		for (int i=0; i < lightCount[type]; ++i)
 		{
@@ -538,7 +537,7 @@ Vector3i FFPLighting::getLightCount() const
 //-----------------------------------------------------------------------
 const String& FFPLightingFactory::getType() const
 {
-	return FFPLighting::Type;
+	return SRS_PER_VERTEX_LIGHTING;
 }
 
 //-----------------------------------------------------------------------
@@ -549,29 +548,16 @@ SubRenderState*	FFPLightingFactory::createInstance(ScriptCompiler* compiler,
         return NULL;
 
     auto it = prop->values.begin();
-    String val;
-
-    if(!SGScriptTranslator::getString(*it, &val))
-    {
-        compiler->addError(ScriptCompiler::CE_INVALIDPARAMETERS, prop->file, prop->line);
-        return NULL;
-    }
 
     SubRenderState* ret = NULL;
-    if (val == "ffp")
+    if ((*it++)->getString() == "ffp")
     {
         ret = createOrRetrieveInstance(translator);
     }
 
     if(ret && prop->values.size() >= 2)
     {
-        if(!SGScriptTranslator::getString(*it, &val))
-        {
-            compiler->addError(ScriptCompiler::CE_INVALIDPARAMETERS, prop->file, prop->line);
-            return NULL;
-        }
-
-        static_cast<FFPLighting*>(ret)->setNormaliseEnabled(val == "normalised");
+        ret->setParameter((*it)->getString(), "true"); // normalise
     }
 
     return ret;
