@@ -42,7 +42,7 @@ namespace Ogre
     /** \addtogroup Core
     *  @{
     */
-    /** \addtogroup General
+    /** \addtogroup Script
     *  @{
     */
     /** These enums hold the types of the concrete parsed nodes */
@@ -103,6 +103,8 @@ namespace Ogre
         virtual AbstractNode *clone() const = 0;
         /// Returns a string value depending on the type of the AbstractNode.
         virtual const String& getValue() const = 0;
+        /// Returns the string content of the node for ANT_ATOM. Empty string otherwise.
+        const String& getString() const;
     };
 
     /** This is an abstract node which cannot be broken down further */
@@ -113,10 +115,15 @@ namespace Ogre
         uint32 id;
     public:
         AtomAbstractNode(AbstractNode *ptr);
-        AbstractNode *clone() const;
-        const String& getValue() const { return value; }
+        AbstractNode *clone() const override;
+        const String& getValue() const override { return value; }
     };
 
+    inline const String& AbstractNode::getString() const
+    {
+        return type == ANT_ATOM ? static_cast<const AtomAbstractNode*>(this)->value : BLANKSTRING;
+    }
+
     /** This specific abstract node represents a script object */
     class _OgreExport ObjectAbstractNode : public AbstractNode
     {
@@ -132,8 +139,8 @@ namespace Ogre
         AbstractNodeList overrides; // For use when processing object inheritance and overriding
     public:
         ObjectAbstractNode(AbstractNode *ptr);
-        AbstractNode *clone() const;
-        const String& getValue() const { return cls; }
+        AbstractNode *clone() const override;
+        const String& getValue() const override { return cls; }
 
         void addVariable(const String &name);
         void setVariable(const String &name, const String &value);
@@ -150,8 +157,8 @@ namespace Ogre
         AbstractNodeList values;
     public:
         PropertyAbstractNode(AbstractNode *ptr);
-        AbstractNode *clone() const;
-        const String& getValue() const { return name; }
+        AbstractNode *clone() const override;
+        const String& getValue() const override { return name; }
     };
 
     /** This abstract node represents an import statement */
@@ -161,8 +168,8 @@ namespace Ogre
         String target, source;
     public:
         ImportAbstractNode();
-        AbstractNode *clone() const;
-        const String& getValue() const { return target; }
+        AbstractNode *clone() const override;
+        const String& getValue() const override { return target; }
     };
 
     /** This abstract node represents a variable assignment */
@@ -172,8 +179,8 @@ namespace Ogre
         String name;
     public:
         VariableAccessAbstractNode(AbstractNode *ptr);
-        AbstractNode *clone() const;
-        const String& getValue() const { return name; }
+        AbstractNode *clone() const override;
+        const String& getValue() const override { return name; }
     };
 
     class ScriptCompilerEvent;
@@ -219,10 +226,6 @@ namespace Ogre
         bool compile(const String &str, const String &source, const String &group);
         /// Compiles resources from the given concrete node list
         bool compile(const ConcreteNodeListPtr &nodes, const String &group);
-        /// Generates the AST from the given string script
-        AbstractNodeListPtr _generateAST(const String &str, const String &source, bool doImports = false, bool doObjects = false, bool doVariables = false);
-        /// Compiles the given abstract syntax tree
-        bool _compile(AbstractNodeListPtr nodes, const String &group, bool doImports = true, bool doObjects = true, bool doVariables = true);
         /// Adds the given error to the compiler's list of errors
         void addError(uint32 code, const String &file, int line, const String &msg = "");
         /// Sets the listener used by the compiler
@@ -446,11 +449,11 @@ namespace Ogre
         /// Adds a script extension that can be handled (e.g. *.material, *.pu, etc.)
         void addScriptPattern(const String &pattern);
         /// @copydoc ScriptLoader::getScriptPatterns
-        const StringVector& getScriptPatterns(void) const;
+        const StringVector& getScriptPatterns(void) const override;
         /// @copydoc ScriptLoader::parseScript
-        void parseScript(DataStreamPtr& stream, const String& groupName);
+        void parseScript(DataStreamPtr& stream, const String& groupName) override;
         /// @copydoc ScriptLoader::getLoadingOrder
-        Real getLoadingOrder(void) const;
+        Real getLoadingOrder(void) const override;
 
         /// @copydoc Singleton::getSingleton()
         static ScriptCompilerManager& getSingleton(void);
@@ -458,8 +461,8 @@ namespace Ogre
         static ScriptCompilerManager* getSingletonPtr(void);
     };
 
-    // Standard event types
-    class _OgreExport PreApplyTextureAliasesScriptCompilerEvent : public ScriptCompilerEvent
+    /// @deprecated do not use
+    class OGRE_DEPRECATED _OgreExport PreApplyTextureAliasesScriptCompilerEvent : public ScriptCompilerEvent
     {
     public:
         Material *mMaterial;
@@ -523,19 +526,8 @@ namespace Ogre
         {}  
     };
 
-    class _OgreExport CreateHighLevelGpuProgramScriptCompilerEvent : public ScriptCompilerEvent
-    {
-    public:
-        String mFile, mName, mResourceGroup, mSource, mLanguage;
-        GpuProgramType mProgramType;
-        static String eventType;
-
-        CreateHighLevelGpuProgramScriptCompilerEvent(const String &file, const String &name, const String &resourceGroup, const String &source, 
-            const String &language, GpuProgramType programType)
-            :ScriptCompilerEvent(eventType), mFile(file), mName(name), mResourceGroup(resourceGroup), mSource(source), 
-             mLanguage(language), mProgramType(programType)
-        {}  
-    };
+    /// @deprecated use CreateGpuProgramScriptCompilerEvent
+    typedef OGRE_DEPRECATED CreateGpuProgramScriptCompilerEvent CreateHighLevelGpuProgramScriptCompilerEvent;
 
     class _OgreExport CreateGpuSharedParametersScriptCompilerEvent : public ScriptCompilerEvent
     {
@@ -842,8 +834,7 @@ namespace Ogre
             ID_DEPTH_FAIL_OP,
             ID_PASS_OP,
             ID_TWO_SIDED,
-            ID_READ_BACK_AS_TEXTURE,
-        // Suport for shader model 5.0
+        // Support for shader model 5.0
         // More program IDs
         ID_TESSELLATION_HULL_PROGRAM,
         ID_TESSELLATION_DOMAIN_PROGRAM,
@@ -857,15 +848,15 @@ namespace Ogre
         ID_TESSELLATION_DOMAIN,
         ID_COMPUTE,
 
-        // Support for subroutine
-        ID_SUBROUTINE,
-
         // added during 1.11. re-sort for 1.12
         ID_LINE_WIDTH,
         ID_SAMPLER,
         ID_SAMPLER_REF,
         ID_THREAD_GROUPS,
         ID_RENDER_CUSTOM,
+        ID_AUTO,
+        ID_CAMERA,
+        ID_ALIGN_TO_FACE,
 
         ID_END_BUILTIN_IDS
     };
