@@ -130,10 +130,9 @@ namespace Ogre {
     //---------------------------------------------------------------------
     void Animation::destroyAllNodeTracks(void)
     {
-        NodeTrackList::iterator i;
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& t : mNodeTrackList)
         {
-            OGRE_DELETE i->second;
+            OGRE_DELETE t.second;
         }
         mNodeTrackList.clear();
         _keyFrameListChanged();
@@ -205,10 +204,9 @@ namespace Ogre {
     //---------------------------------------------------------------------
     void Animation::destroyAllNumericTracks(void)
     {
-        NumericTrackList::iterator i;
-        for (i = mNumericTrackList.begin(); i != mNumericTrackList.end(); ++i)
+        for (auto& t : mNumericTrackList)
         {
-            OGRE_DELETE i->second;
+            OGRE_DELETE t.second;
         }
         mNumericTrackList.clear();
         _keyFrameListChanged();
@@ -310,22 +308,18 @@ namespace Ogre {
         // Calculate time index for fast keyframe search
         TimeIndex timeIndex = _getTimeIndex(timePos);
 
-        NodeTrackList::iterator i;
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& i : mNodeTrackList)
         {
-            i->second->apply(timeIndex, weight, scale);
+            i.second->apply(timeIndex, weight, scale);
         }
-        NumericTrackList::iterator j;
-        for (j = mNumericTrackList.begin(); j != mNumericTrackList.end(); ++j)
+        for (auto& j : mNumericTrackList)
         {
-            j->second->apply(timeIndex, weight, scale);
+            j.second->apply(timeIndex, weight, scale);
         }
-        VertexTrackList::iterator k;
-        for (k = mVertexTrackList.begin(); k != mVertexTrackList.end(); ++k)
+        for (auto& k : mVertexTrackList)
         {
-            k->second->apply(timeIndex, weight, scale);
+            k.second->apply(timeIndex, weight, scale);
         }
-
     }
     //---------------------------------------------------------------------
     void Animation::applyToNode(Node* node, Real timePos, Real weight, Real scale)
@@ -335,10 +329,9 @@ namespace Ogre {
         // Calculate time index for fast keyframe search
         TimeIndex timeIndex = _getTimeIndex(timePos);
 
-        NodeTrackList::iterator i;
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& t : mNodeTrackList)
         {
-            i->second->applyToNode(node, timeIndex, weight, scale);
+            t.second->applyToNode(node, timeIndex, weight, scale);
         }
     }
     //---------------------------------------------------------------------
@@ -350,12 +343,11 @@ namespace Ogre {
         // Calculate time index for fast keyframe search
         TimeIndex timeIndex = _getTimeIndex(timePos);
 
-        NodeTrackList::iterator i;
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& t : mNodeTrackList)
         {
             // get bone to apply to 
-            Bone* b = skel->getBone(i->first);
-            i->second->applyToNode(b, timeIndex, weight, scale);
+            Bone* b = skel->getBone(t.first);
+            t.second->applyToNode(b, timeIndex, weight, scale);
         }
 
 
@@ -367,15 +359,13 @@ namespace Ogre {
         _applyBaseKeyFrame();
 
         // Calculate time index for fast keyframe search
-      TimeIndex timeIndex = _getTimeIndex(timePos);
+        TimeIndex timeIndex = _getTimeIndex(timePos);
 
-      NodeTrackList::iterator i;
-      for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
-      {
-        // get bone to apply to 
-        Bone* b = skel->getBone(i->first);
-        i->second->applyToNode(b, timeIndex, (*blendMask)[b->getHandle()] * weight, scale);
-      }
+        for (auto& t : mNodeTrackList)
+        {
+            Bone* b = skel->getBone(t.first);
+            t.second->applyToNode(b, timeIndex, (*blendMask)[b->getHandle()] * weight, scale);
+        }
     }
     //---------------------------------------------------------------------
     void Animation::apply(Entity* entity, Real timePos, Real weight, 
@@ -387,10 +377,10 @@ namespace Ogre {
         TimeIndex timeIndex = _getTimeIndex(timePos);
 
         VertexTrackList::iterator i;
-        for (i = mVertexTrackList.begin(); i != mVertexTrackList.end(); ++i)
+        for (auto& t : mVertexTrackList)
         {
-            unsigned short handle = i->first;
-            VertexAnimationTrack* track = i->second;
+            unsigned short handle = t.first;
+            VertexAnimationTrack* track = t.second;
 
             VertexData* swVertexData;
             VertexData* hwVertexData;
@@ -436,10 +426,9 @@ namespace Ogre {
         // Calculate time index for fast keyframe search
         _getTimeIndex(timePos);
 
-        NumericTrackList::iterator j;
-        for (j = mNumericTrackList.begin(); j != mNumericTrackList.end(); ++j)
+        for (auto& j : mNumericTrackList)
         {
-            j->second->applyToAnimable(anim, timePos, weight, scale);
+            j.second->applyToAnimable(anim, timePos, weight, scale);
         }
    }
     //---------------------------------------------------------------------
@@ -450,10 +439,9 @@ namespace Ogre {
         // Calculate time index for fast keyframe search
         TimeIndex timeIndex = _getTimeIndex(timePos);
 
-        VertexTrackList::iterator k;
-        for (k = mVertexTrackList.begin(); k != mVertexTrackList.end(); ++k)
+        for (auto& k : mVertexTrackList)
         {
-            k->second->applyToVertexData(data, timeIndex, weight);
+            k.second->applyToVertexData(data, timeIndex, weight);
         }
     }
     //---------------------------------------------------------------------
@@ -522,25 +510,21 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Animation::_collectIdentityNodeTracks(TrackHandleList& tracks) const
     {
-        NodeTrackList::const_iterator i, iend;
-        iend = mNodeTrackList.end();
-        for (i = mNodeTrackList.begin(); i != iend; ++i)
+        for (auto& t : mNodeTrackList)
         {
-            const NodeAnimationTrack* track = i->second;
+            const NodeAnimationTrack* track = t.second;
             if (track->hasNonZeroKeyFrames())
             {
-                tracks.erase(i->first);
+                tracks.erase(t.first);
             }
         }
     }
     //-----------------------------------------------------------------------
     void Animation::_destroyNodeTracks(const TrackHandleList& tracks)
     {
-        TrackHandleList::const_iterator t, tend;
-        tend = tracks.end();
-        for (t = tracks.begin(); t != tend; ++t)
+        for (auto t : tracks)
         {
-            destroyNodeTrack(*t);
+            destroyNodeTrack(t);
         }
     }
     //-----------------------------------------------------------------------
@@ -548,24 +532,22 @@ namespace Ogre {
     {
         // Iterate over the node tracks and identify those with no useful keyframes
         std::list<unsigned short> tracksToDestroy;
-        NodeTrackList::iterator i;
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& t : mNodeTrackList)
         {
-            NodeAnimationTrack* track = i->second;
+            NodeAnimationTrack* track = t.second;
             if (discardIdentityTracks && !track->hasNonZeroKeyFrames())
             {
                 // mark the entire track for destruction
-                tracksToDestroy.push_back(i->first);
+                tracksToDestroy.push_back(t.first);
             }
             else
             {
                 track->optimise();
             }
-
         }
 
         // Now destroy the tracks we marked for death
-        for(unsigned short & h : tracksToDestroy)
+        for(unsigned short& h : tracksToDestroy)
         {
             destroyNodeTrack(h);
         }
@@ -575,28 +557,25 @@ namespace Ogre {
     {
         // Iterate over the node tracks and identify those with no useful keyframes
         std::list<unsigned short> tracksToDestroy;
-        VertexTrackList::iterator i;
-        for (i = mVertexTrackList.begin(); i != mVertexTrackList.end(); ++i)
+        for (auto& t : mVertexTrackList)
         {
-            VertexAnimationTrack* track = i->second;
+            VertexAnimationTrack* track = t.second;
             if (!track->hasNonZeroKeyFrames())
             {
                 // mark the entire track for destruction
-                tracksToDestroy.push_back(i->first);
+                tracksToDestroy.push_back(t.first);
             }
             else
             {
                 track->optimise();
             }
-
         }
 
         // Now destroy the tracks we marked for death
-        for(unsigned short & h : tracksToDestroy)
+        for(unsigned short& h : tracksToDestroy)
         {
             destroyVertexTrack(h);
         }
-
     }
     //-----------------------------------------------------------------------
     Animation* Animation::clone(const String& newName) const
@@ -648,39 +627,35 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Animation::buildKeyFrameTimeList(void) const
     {
-        NodeTrackList::const_iterator i;
-        NumericTrackList::const_iterator j;
-        VertexTrackList::const_iterator k;
-
         // Clear old keyframe times
         mKeyFrameTimes.clear();
 
         // Collect all keyframe times from each track
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& i : mNodeTrackList)
         {
-            i->second->_collectKeyFrameTimes(mKeyFrameTimes);
+            i.second->_collectKeyFrameTimes(mKeyFrameTimes);
         }
-        for (j = mNumericTrackList.begin(); j != mNumericTrackList.end(); ++j)
+        for (auto& j : mNumericTrackList)
         {
-            j->second->_collectKeyFrameTimes(mKeyFrameTimes);
+            j.second->_collectKeyFrameTimes(mKeyFrameTimes);
         }
-        for (k = mVertexTrackList.begin(); k != mVertexTrackList.end(); ++k)
+        for (auto& k : mVertexTrackList)
         {
-            k->second->_collectKeyFrameTimes(mKeyFrameTimes);
+            k.second->_collectKeyFrameTimes(mKeyFrameTimes);
         }
 
         // Build global index to local index map for each track
-        for (i = mNodeTrackList.begin(); i != mNodeTrackList.end(); ++i)
+        for (auto& i : mNodeTrackList)
         {
-            i->second->_buildKeyFrameIndexMap(mKeyFrameTimes);
+            i.second->_buildKeyFrameIndexMap(mKeyFrameTimes);
         }
-        for (j = mNumericTrackList.begin(); j != mNumericTrackList.end(); ++j)
+        for (auto& j : mNumericTrackList)
         {
-            j->second->_buildKeyFrameIndexMap(mKeyFrameTimes);
+            j.second->_buildKeyFrameIndexMap(mKeyFrameTimes);
         }
-        for (k = mVertexTrackList.begin(); k != mVertexTrackList.end(); ++k)
+        for (auto& k : mVertexTrackList)
         {
-            k->second->_buildKeyFrameIndexMap(mKeyFrameTimes);
+            k.second->_buildKeyFrameIndexMap(mKeyFrameTimes);
         }
 
         // Reset dirty flag
@@ -724,7 +699,7 @@ namespace Ogre {
             
             if (baseAnim)
             {
-                for (auto & i : mNodeTrackList)
+                for (auto& i : mNodeTrackList)
                 {
                     NodeAnimationTrack* track = i.second;
                     
@@ -739,7 +714,7 @@ namespace Ogre {
                     track->_applyBaseKeyFrame(&kf);
                 }
                 
-                for (auto & i : mVertexTrackList)
+                for (auto& i : mVertexTrackList)
                 {
                     VertexAnimationTrack* track = i.second;
                     
@@ -775,8 +750,6 @@ namespace Ogre {
     {
         return mContainer;
     }
-    
-
 }
 
 
