@@ -35,16 +35,14 @@ namespace Ogre {
 #define TEMP_INITIAL_VERTEX_SIZE TEMP_VERTEXSIZE_GUESS * TEMP_INITIAL_SIZE
 #define TEMP_INITIAL_INDEX_SIZE sizeof(uint32) * TEMP_INITIAL_SIZE
     //-----------------------------------------------------------------------------
-    ManualObject::ManualObject(const String& name)
-        : MovableObject(name),
-          mDynamic(false), mCurrentSection(0), mCurrentUpdating(false), mFirstVertex(true),
-          mTempVertexPending(false),
-          mTempVertexBuffer(0), mTempVertexSize(TEMP_INITIAL_VERTEX_SIZE),
-          mTempIndexBuffer(0), mTempIndexSize(TEMP_INITIAL_INDEX_SIZE),
-          mDeclSize(0), mEstVertexCount(0), mEstIndexCount(0), mTexCoordIndex(0), 
-          mRadius(0), mAnyIndexed(false), mEdgeList(0), 
-          mUseIdentityProjection(false), mUseIdentityView(false), mKeepDeclarationOrder(false)
-    {
+ManualObject::ManualObject(const String& name)
+    : MovableObject(name), mBufferUsage(HardwareBuffer::HBU_STATIC_WRITE_ONLY), mCurrentSection(0),
+      mCurrentUpdating(false), mFirstVertex(true), mTempVertexPending(false), mTempVertexBuffer(0),
+      mTempVertexSize(TEMP_INITIAL_VERTEX_SIZE), mTempIndexBuffer(0),
+      mTempIndexSize(TEMP_INITIAL_INDEX_SIZE), mDeclSize(0), mEstVertexCount(0), mEstIndexCount(0),
+      mTexCoordIndex(0), mRadius(0), mAnyIndexed(false), mEdgeList(0), mUseIdentityProjection(false),
+      mUseIdentityView(false), mKeepDeclarationOrder(false)
+{
     }
     //-----------------------------------------------------------------------------
     ManualObject::~ManualObject()
@@ -55,9 +53,9 @@ namespace Ogre {
     void ManualObject::clear(void)
     {
         resetTempAreas();
-        for (SectionList::iterator i = mSectionList.begin(); i != mSectionList.end(); ++i)
+        for (auto & i : mSectionList)
         {
-            OGRE_DELETE *i;
+            OGRE_DELETE i;
         }
         mSectionList.clear();
         mRadius = 0;
@@ -141,23 +139,18 @@ namespace Ogre {
     void ManualObject::begin(const String& materialName,
         RenderOperation::OperationType opType, const String& groupName)
     {
-        if (mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You cannot call begin() again until after you call end()",
-                "ManualObject::begin");
-        }
+        OgreAssert(!mCurrentSection, "You cannot call begin() again until after you call end()");
 
         // Check that a valid material was provided
         MaterialPtr material = MaterialManager::getSingleton().getByName(materialName, groupName);
 
         if(!material)
         {
-            LogManager::getSingleton().logMessage("Can't assign material " + materialName +
+            LogManager::getSingleton().logError("Can't assign material " + materialName +
                                                   " to the ManualObject " + mName + " because this "
                                                   "Material does not exist in group " + groupName +
                                                   ". Have you forgotten to define it in a "
-                                                  ".material script?", LML_CRITICAL);
+                                                  ".material script?");
 
             material = MaterialManager::getSingleton().getDefaultMaterial();
         }
@@ -174,12 +167,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------------
     void ManualObject::begin(const MaterialPtr& mat, RenderOperation::OperationType opType)
     {
-      if (mCurrentSection)
-      {
-          OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-              "You cannot call begin() again until after you call end()",
-              "ManualObject::begin");
-      }
+      OgreAssert(!mCurrentSection, "You cannot call begin() again until after you call end()");
 
       if (mat)
       {
@@ -203,19 +191,8 @@ namespace Ogre {
     //-----------------------------------------------------------------------------
     void ManualObject::beginUpdate(size_t sectionIndex)
     {
-        if (mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You cannot call begin() again until after you call end()",
-                "ManualObject::beginUpdate");
-        }
-        if (sectionIndex >= mSectionList.size())
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "Invalid section index - out of range.",
-                "ManualObject::beginUpdate");
-        }
-        mCurrentSection = mSectionList[sectionIndex];
+        OgreAssert(!mCurrentSection, "You cannot call begin() again until after you call end()");
+        mCurrentSection = mSectionList.at(sectionIndex);
         mCurrentUpdating = true;
         mFirstVertex = true;
         mTexCoordIndex = 0;
@@ -228,277 +205,13 @@ namespace Ogre {
         mDeclSize = rop->vertexData->vertexDeclaration->getVertexSize(0);
     }
     //-----------------------------------------------------------------------------
-    void ManualObject::position(const Vector3& pos)
+    void ManualObject::declareElement(VertexElementType t, VertexElementSemantic s)
     {
-        position(pos.x, pos.y, pos.z);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::position(float x, float y, float z)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::position");
-        }
-        if (mTempVertexPending)
-        {
-            // bake current vertex
-            copyTempVertexToBuffer();
-            mFirstVertex = false;
-        }
-
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT3, VES_POSITION).getSize();
-        }
-
-        mTempVertex.position.x = x;
-        mTempVertex.position.y = y;
-        mTempVertex.position.z = z;
-
-        // update bounds
-        mAABB.merge(mTempVertex.position);
-        mRadius = std::max(mRadius, mTempVertex.position.length());
-
-        // reset current texture coord
-        mTexCoordIndex = 0;
-
-        mTempVertexPending = true;
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::normal(const Vector3& norm)
-    {
-        normal(norm.x, norm.y, norm.z);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::normal(float x, float y, float z)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::normal");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT3, VES_NORMAL).getSize();
-        }
-        mTempVertex.normal.x = x;
-        mTempVertex.normal.y = y;
-        mTempVertex.normal.z = z;
-    }
-
-    //-----------------------------------------------------------------------------
-    void ManualObject::tangent(const Vector3& tan)
-    {
-        tangent(tan.x, tan.y, tan.z);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::tangent(float x, float y, float z)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::tangent");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT3, VES_TANGENT).getSize();
-        }
-        mTempVertex.tangent.x = x;
-        mTempVertex.tangent.y = y;
-        mTempVertex.tangent.z = z;
-    }
-
-    //-----------------------------------------------------------------------------
-    void ManualObject::textureCoord(float u)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::textureCoord");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT1, VES_TEXTURE_COORDINATES, mTexCoordIndex).getSize();
-        }
-        mTempVertex.texCoordDims[mTexCoordIndex] = 1;
-        mTempVertex.texCoord[mTexCoordIndex].x = u;
-
-        ++mTexCoordIndex;
-
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::textureCoord(float u, float v)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::textureCoord");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT2, VES_TEXTURE_COORDINATES, mTexCoordIndex).getSize();
-        }
-        mTempVertex.texCoordDims[mTexCoordIndex] = 2;
-        mTempVertex.texCoord[mTexCoordIndex].x = u;
-        mTempVertex.texCoord[mTexCoordIndex].y = v;
-
-        ++mTexCoordIndex;
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::textureCoord(float u, float v, float w)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::textureCoord");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT3, VES_TEXTURE_COORDINATES, mTexCoordIndex).getSize();
-        }
-        mTempVertex.texCoordDims[mTexCoordIndex] = 3;
-        mTempVertex.texCoord[mTexCoordIndex].x = u;
-        mTempVertex.texCoord[mTexCoordIndex].y = v;
-        mTempVertex.texCoord[mTexCoordIndex].z = w;
-
-        ++mTexCoordIndex;
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::textureCoord(float x, float y, float z, float w)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::textureCoord");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_FLOAT4, VES_TEXTURE_COORDINATES, mTexCoordIndex).getSize();
-        }
-        mTempVertex.texCoordDims[mTexCoordIndex] = 4;
-        mTempVertex.texCoord[mTexCoordIndex].x = x;
-        mTempVertex.texCoord[mTexCoordIndex].y = y;
-        mTempVertex.texCoord[mTexCoordIndex].z = z;
-        mTempVertex.texCoord[mTexCoordIndex].w = w;
-
-        ++mTexCoordIndex;
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::textureCoord(const Vector2& uv)
-    {
-        textureCoord(uv.x, uv.y);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::textureCoord(const Vector3& uvw)
-    {
-        textureCoord(uvw.x, uvw.y, uvw.z);
-    }
-    //---------------------------------------------------------------------
-    void ManualObject::textureCoord(const Vector4& xyzw)
-    {
-        textureCoord(xyzw.x, xyzw.y, xyzw.z, xyzw.w);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::colour(const ColourValue& col)
-    {
-        colour(col.r, col.g, col.b, col.a);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::colour(float r, float g, float b, float a)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::colour");
-        }
-        if (mFirstVertex && !mCurrentUpdating)
-        {
-            // defining declaration
-            mDeclSize += mCurrentSection->getRenderOperation()->vertexData->vertexDeclaration
-                ->addElement(0, mDeclSize, VET_COLOUR, VES_DIFFUSE).getSize();
-        }
-        mTempVertex.colour.r = r;
-        mTempVertex.colour.g = g;
-        mTempVertex.colour.b = b;
-        mTempVertex.colour.a = a;
-
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::index(uint32 idx)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::index");
-        }
-        mAnyIndexed = true;
-        if (idx >= 65536)
-            mCurrentSection->set32BitIndices(true);
-
-        // make sure we have index data
-        RenderOperation* rop = mCurrentSection->getRenderOperation();
-        if (!rop->indexData)
-        {
-            rop->indexData = OGRE_NEW IndexData();
-            rop->indexData->indexCount = 0;
-        }
-        rop->useIndexes = true;
-        resizeTempIndexBufferIfNeeded(++rop->indexData->indexCount);
-
-        mTempIndexBuffer[rop->indexData->indexCount - 1] = idx;
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::triangle(uint32 i1, uint32 i2, uint32 i3)
-    {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You must call begin() before this method",
-                "ManualObject::index");
-        }
-        if (mCurrentSection->getRenderOperation()->operationType !=
-            RenderOperation::OT_TRIANGLE_LIST)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "This method is only valid on triangle lists",
-                "ManualObject::index");
-        }
-
-        index(i1);
-        index(i2);
-        index(i3);
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::quad(uint32 i1, uint32 i2, uint32 i3, uint32 i4)
-    {
-        // first tri
-        triangle(i1, i2, i3);
-        // second tri
-        triangle(i3, i4, i1);
+        // defining declaration
+        ushort idx = s == VES_TEXTURE_COORDINATES ? mTexCoordIndex : 0;
+        mDeclSize += mCurrentSection->getRenderOperation()
+                         ->vertexData->vertexDeclaration->addElement(0, mDeclSize, t, s, idx)
+                         .getSize();
     }
     //-----------------------------------------------------------------------------
     size_t ManualObject::getCurrentVertexCount() const
@@ -547,12 +260,10 @@ namespace Ogre {
         char* pBase = mTempVertexBuffer + (mDeclSize * (rop->vertexData->vertexCount-1));
         const VertexDeclaration::VertexElementList& elemList =
             rop->vertexData->vertexDeclaration->getElements();
-        for (VertexDeclaration::VertexElementList::const_iterator i = elemList.begin();
-            i != elemList.end(); ++i)
+        for (const auto & elem : elemList)
         {
             float* pFloat = 0;
             RGBA* pRGBA = 0;
-            const VertexElement& elem = *i;
             switch(elem.getType())
             {
             case VET_FLOAT1:
@@ -562,9 +273,7 @@ namespace Ogre {
                 OgreAssert(elem.getSemantic() != VES_DIFFUSE, "must use VET_COLOUR");
                 elem.baseVertexPointerToElement(pBase, &pFloat);
                 break;
-            case VET_COLOUR:
-            case VET_COLOUR_ABGR:
-            case VET_COLOUR_ARGB:
+            case VET_UBYTE4_NORM:
                 OgreAssert(elem.getSemantic() == VES_DIFFUSE, "must use VES_DIFFUSE");
                 elem.baseVertexPointerToElement(pBase, &pRGBA);
                 break;
@@ -573,8 +282,6 @@ namespace Ogre {
                 break;
             };
 
-
-            RenderSystem* rs;
             unsigned short dims;
             switch(elem.getSemantic())
             {
@@ -599,25 +306,7 @@ namespace Ogre {
                     *pFloat++ = mTempVertex.texCoord[elem.getIndex()][t];
                 break;
             case VES_DIFFUSE:
-                rs = Root::getSingleton().getRenderSystem();
-                if (rs)
-                {
-                    rs->convertColourValue(mTempVertex.colour, pRGBA++);
-                }
-                else
-                {
-                    switch(elem.getType())
-                    {
-                        case VET_COLOUR_ABGR:
-                            *pRGBA++ = mTempVertex.colour.getAsABGR();
-                            break;
-                        case VET_COLOUR_ARGB:
-                            *pRGBA++ = mTempVertex.colour.getAsARGB();
-                            break;
-                        default:
-                            *pRGBA++ = mTempVertex.colour.getAsRGBA();
-                    }
-                }
+                *pRGBA++ = mTempVertex.colour.getAsABGR();
                 break;
             default:
                 OgreAssert(false, "invalid semantic");
@@ -630,12 +319,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------------
     ManualObject::ManualObjectSection* ManualObject::end(void)
     {
-        if (!mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You cannot call end() until after you call begin()",
-                "ManualObject::end");
-        }
+        OgreAssert(mCurrentSection, "You cannot call end() until after you call begin()");
         if (mTempVertexPending)
         {
             // bake current vertex
@@ -700,26 +384,17 @@ namespace Ogre {
                 // to allow for user-configured growth area
                 size_t vertexCount = std::max(rop->vertexData->vertexCount, 
                     mEstVertexCount);
-                vbuf =
-                    HardwareBufferManager::getSingleton().createVertexBuffer(
-                        mDeclSize,
-                        vertexCount,
-                        mDynamic? HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY : 
-                            HardwareBuffer::HBU_STATIC_WRITE_ONLY);
+                vbuf = HardwareBufferManager::getSingleton().createVertexBuffer(mDeclSize, vertexCount,
+                                                                                mBufferUsage);
                 rop->vertexData->vertexBufferBinding->setBinding(0, vbuf);
             }
             if (ibufNeedsCreating)
             {
                 // Make the index buffer larger if estimated index count higher
                 // to allow for user-configured growth area
-                size_t indexCount = std::max(rop->indexData->indexCount, 
-                    mEstIndexCount);
-                rop->indexData->indexBuffer =
-                    HardwareBufferManager::getSingleton().createIndexBuffer(
-                        indexType,
-                        indexCount,
-                        mDynamic? HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY : 
-                            HardwareBuffer::HBU_STATIC_WRITE_ONLY);
+                size_t indexCount = std::max(rop->indexData->indexCount, mEstIndexCount);
+                rop->indexData->indexBuffer = HardwareBufferManager::getSingleton().createIndexBuffer(
+                    indexType, indexCount, mBufferUsage);
             }
             // Write vertex data
             vbuf->writeData(
@@ -768,46 +443,12 @@ namespace Ogre {
         return result;
     }
     //-----------------------------------------------------------------------------
-    void ManualObject::setMaterialName(size_t idx, const String& name, const String& group)
-    {
-        if (idx >= mSectionList.size())
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "Index out of bounds!",
-                "ManualObject::setMaterialName");
-        }
-
-        mSectionList[idx]->setMaterialName(name, group);
-
-    }
-    //-----------------------------------------------------------------------------
-    void ManualObject::setMaterial(size_t subIndex, const MaterialPtr &mat)
-    {
-        if (subIndex >= mSectionList.size())
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "Index out of bounds!",
-                "ManualObject::setMaterial");
-        }
-
-        mSectionList[subIndex]->setMaterial(mat);
-    }
-    //-----------------------------------------------------------------------------
     MeshPtr ManualObject::convertToMesh(const String& meshName, const String& groupName)
     {
-        if (mCurrentSection)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "You cannot call convertToMesh() whilst you are in the middle of "
-                "defining the object; call end() first.",
-                "ManualObject::convertToMesh");
-        }
-        if (mSectionList.empty())
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                "No data defined to convert to a mesh.",
-                "ManualObject::convertToMesh");
-        }
+        OgreAssert(!mCurrentSection, "You cannot call convertToMesh() whilst you are in the middle of "
+                                     "defining the object; call end() first.");
+        OgreAssert(!mSectionList.empty(), "No data defined to convert to a mesh.");
+
         MeshPtr m = MeshManager::getSingleton().createManual(meshName, groupName);
 
         for (auto sec : mSectionList)
@@ -828,9 +469,9 @@ namespace Ogre {
     void ManualObject::setUseIdentityProjection(bool useIdentityProjection)
     {
         // Set existing
-        for (SectionList::iterator i = mSectionList.begin(); i != mSectionList.end(); ++i)
+        for (auto & i : mSectionList)
         {
-            (*i)->setUseIdentityProjection(useIdentityProjection);
+            i->setUseIdentityProjection(useIdentityProjection);
         }
         
         // Save setting for future sections
@@ -840,53 +481,29 @@ namespace Ogre {
     void ManualObject::setUseIdentityView(bool useIdentityView)
     {
         // Set existing
-        for (SectionList::iterator i = mSectionList.begin(); i != mSectionList.end(); ++i)
+        for (auto & i : mSectionList)
         {
-            (*i)->setUseIdentityView(useIdentityView);
+            i->setUseIdentityView(useIdentityView);
         }
 
         // Save setting for future sections
         mUseIdentityView = useIdentityView;
     }
-    //-----------------------------------------------------------------------
-    ManualObject::ManualObjectSection* ManualObject::getSection(unsigned int inIndex) const
-    {
-        if (inIndex >= mSectionList.size())
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-            "Index out of bounds.",
-            "ManualObject::getSection");
-        return mSectionList[inIndex];
-    }
-    //-----------------------------------------------------------------------
-    unsigned int ManualObject::getNumSections(void) const
-    {
-        return static_cast< unsigned int >( mSectionList.size() );
-    }
     //-----------------------------------------------------------------------------
     const String& ManualObject::getMovableType(void) const
     {
         return ManualObjectFactory::FACTORY_TYPE_NAME;
     }
     //-----------------------------------------------------------------------------
-    const AxisAlignedBox& ManualObject::getBoundingBox(void) const
-    {
-        return mAABB;
-    }
-    //-----------------------------------------------------------------------------
-    Real ManualObject::getBoundingRadius(void) const
-    {
-        return mRadius;
-    }
-    //-----------------------------------------------------------------------------
     void ManualObject::_updateRenderQueue(RenderQueue* queue)
     {
         // To be used when order of creation must be kept while rendering
         unsigned short priority = queue->getDefaultRenderablePriority();
 
-        for (SectionList::iterator i = mSectionList.begin(); i != mSectionList.end(); ++i)
+        for (auto & i : mSectionList)
         {
             // Skip empty sections (only happens if non-empty first, then updated)
-            RenderOperation* rop = (*i)->getRenderOperation();
+            RenderOperation* rop = i->getRenderOperation();
             if (rop->vertexData->vertexCount == 0 ||
                 (rop->useIndexes && rop->indexData->indexCount == 0))
                 continue;
@@ -894,21 +511,21 @@ namespace Ogre {
             if (mRenderQueuePrioritySet)
             {
                 assert(mRenderQueueIDSet == true);
-                queue->addRenderable(*i, mRenderQueueID, mRenderQueuePriority);
+                queue->addRenderable(i, mRenderQueueID, mRenderQueuePriority);
             }
             else if (mRenderQueueIDSet)
-                queue->addRenderable(*i, mRenderQueueID, mKeepDeclarationOrder ? priority++ : queue->getDefaultRenderablePriority());
+                queue->addRenderable(i, mRenderQueueID, mKeepDeclarationOrder ? priority++ : queue->getDefaultRenderablePriority());
             else
-                queue->addRenderable(*i, queue->getDefaultQueueGroup(), mKeepDeclarationOrder ? priority++ : queue->getDefaultRenderablePriority());
+                queue->addRenderable(i, queue->getDefaultQueueGroup(), mKeepDeclarationOrder ? priority++ : queue->getDefaultRenderablePriority());
         }
     }
     //-----------------------------------------------------------------------------
     void ManualObject::visitRenderables(Renderable::Visitor* visitor, 
         bool debugRenderables)
     {
-        for (SectionList::iterator i = mSectionList.begin(); i != mSectionList.end(); ++i)
+        for (auto & i : mSectionList)
         {
-            visitor->visit(*i, 0, false);
+            visitor->visit(i, 0, false);
         }
 
     }
@@ -921,9 +538,9 @@ namespace Ogre {
             EdgeListBuilder eb;
             size_t vertexSet = 0;
             bool anyBuilt = false;
-            for (SectionList::iterator i = mSectionList.begin(); i != mSectionList.end(); ++i)
+            for (auto & i : mSectionList)
             {
-                RenderOperation* rop = (*i)->getRenderOperation();
+                RenderOperation* rop = i->getRenderOperation();
                 // Only indexed triangle geometry supported for stencil shadows
                 if (rop->useIndexes && rop->indexData->indexCount != 0 && 
                     (rop->operationType == RenderOperation::OT_TRIANGLE_FAN ||
@@ -942,25 +559,15 @@ namespace Ogre {
         }
         return mEdgeList;
     }
-    //---------------------------------------------------------------------
-    bool ManualObject::hasEdgeList()
-    {
-        return getEdgeList() != 0;
-    }
     //-----------------------------------------------------------------------------
-    ShadowCaster::ShadowRenderableListIterator
-    ManualObject::getShadowVolumeRenderableIterator(
-        ShadowTechnique shadowTechnique, const Light* light,
-        HardwareIndexBufferSharedPtr* indexBuffer, size_t* indexBufferUsedSize,
-        bool extrude, Real extrusionDistance, unsigned long flags)
+    const ShadowRenderableList& ManualObject::getShadowVolumeRenderableList(
+        const Light* light, const HardwareIndexBufferPtr& indexBuffer, size_t& indexBufferUsedSize,
+        float extrusionDistance, int flags)
     {
-        assert(indexBuffer && "Only external index buffers are supported right now");       
-
         EdgeData* edgeList = getEdgeList();
         if (!edgeList)
         {
-            return ShadowRenderableListIterator(
-                mShadowRenderables.begin(), mShadowRenderables.end());
+            return mShadowRenderables;
         }
 
         // Calculate the object space light details
@@ -972,10 +579,10 @@ namespace Ogre {
 
         // Init shadow renderable list if required (only allow indexed)
         bool init = mShadowRenderables.empty() && mAnyIndexed;
+        bool extrude = flags & SRF_EXTRUDE_IN_SOFTWARE;
 
         EdgeData::EdgeGroupList::iterator egi;
         ShadowRenderableList::iterator si, siend;
-        ManualObjectSectionShadowRenderable* esr = 0;
         SectionList::iterator seci;
         if (init)
             mShadowRenderables.resize(edgeList->edgeGroups.size());
@@ -1001,28 +608,22 @@ namespace Ogre {
                 mat->load();
                 bool vertexProgram = false;
                 Technique* t = mat->getBestTechnique(0, *seci);
-                for (unsigned short p = 0; p < t->getNumPasses(); ++p)
+                for (auto pass : t->getPasses())
                 {
-                    Pass* pass = t->getPass(p);
                     if (pass->hasVertexProgram())
                     {
                         vertexProgram = true;
                         break;
                     }
                 }
-                *si = OGRE_NEW ManualObjectSectionShadowRenderable(this, indexBuffer,
-                    egi->vertexData, vertexProgram || !extrude);
+                *si = OGRE_NEW ShadowRenderable(this, indexBuffer, egi->vertexData,
+                                                vertexProgram || !extrude);
             }
-            // Get shadow renderable
-            esr = static_cast<ManualObjectSectionShadowRenderable*>(*si);
-            HardwareVertexBufferSharedPtr esrPositionBuffer = esr->getPositionBuffer();
             // Extrude vertices in software if required
             if (extrude)
             {
-                extrudeVertices(esrPositionBuffer,
-                    egi->vertexData->vertexCount,
-                    lightPos, extrusionDistance);
-
+                extrudeVertices((*si)->getPositionBuffer(), egi->vertexData->vertexCount, lightPos,
+                                extrusionDistance);
             }
 
             ++si;
@@ -1032,14 +633,9 @@ namespace Ogre {
         updateEdgeListLightFacing(edgeList, lightPos);
 
         // Generate indexes and update renderables
-        generateShadowVolume(edgeList, *indexBuffer, *indexBufferUsedSize, 
-            light, mShadowRenderables, flags);
-
-
-        return ShadowRenderableListIterator(
-            mShadowRenderables.begin(), mShadowRenderables.end());
-
+        generateShadowVolume(edgeList, indexBuffer, indexBufferUsedSize, light, mShadowRenderables, flags);
 
+        return mShadowRenderables;
     }
     //-----------------------------------------------------------------------------
     //-----------------------------------------------------------------------------
@@ -1061,7 +657,7 @@ namespace Ogre {
     {
         assert(mMaterial);
         mMaterialName = mMaterial->getName();
-        mMaterialName = mMaterial->getGroup();
+        mGroupName = mMaterial->getGroup();
 
         mRenderOperation.operationType = opType;
         mRenderOperation.useIndexes = false;
@@ -1123,8 +719,7 @@ namespace Ogre {
     Real ManualObject::ManualObjectSection::getSquaredViewDepth(const Ogre::Camera *cam) const
     {
         Node* n = mParent->getParentNode();
-        assert(n);
-        return n->getSquaredViewDepth(cam);
+        return n ? n->getSquaredViewDepth(cam) : 0;
     }
     //-----------------------------------------------------------------------------
     const LightList& ManualObject::ManualObjectSection::getLights(void) const
@@ -1149,75 +744,6 @@ namespace Ogre {
             sm->indexData = mRenderOperation.indexData->clone(true);
         }
     }
-    //--------------------------------------------------------------------------
-    ManualObject::ManualObjectSectionShadowRenderable::ManualObjectSectionShadowRenderable(
-        ManualObject* parent, HardwareIndexBufferSharedPtr* indexBuffer,
-        const VertexData* vertexData, bool createSeparateLightCap,
-        bool isLightCap)
-        : mParent(parent)
-    {
-        // Initialise render op
-        mRenderOp.indexData = OGRE_NEW IndexData();
-        mRenderOp.indexData->indexBuffer = *indexBuffer;
-        mRenderOp.indexData->indexStart = 0;
-        // index start and count are sorted out later
-
-        // Create vertex data which just references position component (and 2 component)
-        mRenderOp.vertexData = OGRE_NEW VertexData();
-        // Map in position data
-        mRenderOp.vertexData->vertexDeclaration->addElement(0,0,VET_FLOAT3, VES_POSITION);
-        ushort origPosBind =
-            vertexData->vertexDeclaration->findElementBySemantic(VES_POSITION)->getSource();
-        mPositionBuffer = vertexData->vertexBufferBinding->getBuffer(origPosBind);
-        mRenderOp.vertexData->vertexBufferBinding->setBinding(0, mPositionBuffer);
-        // Map in w-coord buffer (if present)
-        if(vertexData->hardwareShadowVolWBuffer)
-        {
-            mRenderOp.vertexData->vertexDeclaration->addElement(1,0,VET_FLOAT1, VES_TEXTURE_COORDINATES, 0);
-            mWBuffer = vertexData->hardwareShadowVolWBuffer;
-            mRenderOp.vertexData->vertexBufferBinding->setBinding(1, mWBuffer);
-        }
-        // Use same vertex start as input
-        mRenderOp.vertexData->vertexStart = vertexData->vertexStart;
-
-        if (isLightCap)
-        {
-            // Use original vertex count, no extrusion
-            mRenderOp.vertexData->vertexCount = vertexData->vertexCount;
-        }
-        else
-        {
-            // Vertex count must take into account the doubling of the buffer,
-            // because second half of the buffer is the extruded copy
-            mRenderOp.vertexData->vertexCount =
-                vertexData->vertexCount * 2;
-            if (createSeparateLightCap)
-            {
-                // Create child light cap
-                mLightCap = OGRE_NEW ManualObjectSectionShadowRenderable(parent,
-                    indexBuffer, vertexData, false, true);
-            }
-        }
-    }
-    //--------------------------------------------------------------------------
-    ManualObject::ManualObjectSectionShadowRenderable::~ManualObjectSectionShadowRenderable()
-    {
-        OGRE_DELETE mRenderOp.indexData;
-        OGRE_DELETE mRenderOp.vertexData;
-    }
-    //--------------------------------------------------------------------------
-    void ManualObject::ManualObjectSectionShadowRenderable::getWorldTransforms(
-        Matrix4* xform) const
-    {
-        // pretransformed
-        *xform = mParent->_getParentNodeFullTransform();
-    }
-    //-----------------------------------------------------------------------
-    void ManualObject::ManualObjectSectionShadowRenderable::rebindIndexBuffer(const HardwareIndexBufferSharedPtr& indexBuffer)
-    {
-        mRenderOp.indexData->indexBuffer = indexBuffer;
-        if (mLightCap) mLightCap->rebindIndexBuffer(indexBuffer);
-    }
     //-----------------------------------------------------------------------------
     //-----------------------------------------------------------------------------
     String ManualObjectFactory::FACTORY_TYPE_NAME = "ManualObject";
@@ -1232,12 +758,4 @@ namespace Ogre {
     {
         return OGRE_NEW ManualObject(name);
     }
-    //-----------------------------------------------------------------------------
-    void ManualObjectFactory::destroyInstance( MovableObject* obj)
-    {
-        OGRE_DELETE obj;
-    }
-
-
-
 }
