@@ -439,7 +439,7 @@ namespace Ogre {
 
         }
         void visit(Renderable* rend, ushort lodIndex, bool isDebug, 
-            Any* pAny = 0)
+            Any* pAny = 0) override
         {
             Technique* tech = rend->getTechnique();
             bool techReceivesShadows = tech && tech->getParent()->getReceiveShadows();
