@@ -38,7 +38,7 @@ namespace Ogre {
     */
     struct MinTextureStateChangeHashFunc : public Pass::HashFunc
     {
-        uint32 operator()(const Pass* p) const
+        uint32 operator()(const Pass* p) const override
         {
             OGRE_LOCK_MUTEX(p->mTexUnitChangeMutex);
             uint32 hash = 0;
@@ -61,7 +61,7 @@ namespace Ogre {
     */
     struct MinGpuProgramChangeHashFunc : public Pass::HashFunc
     {
-        uint32 operator()(const Pass* p) const
+        uint32 operator()(const Pass* p) const override
         {
             OGRE_LOCK_MUTEX(p->mGpuProgramChangeMutex);
             uint32 hash = 0;
@@ -480,7 +480,7 @@ namespace Ogre {
         mContentTypeLookupBuilt = false;
     }
     //-----------------------------------------------------------------------
-    void Pass::_getBlendFlags(SceneBlendType type, SceneBlendFactor& source, SceneBlendFactor& dest)
+    static void _getBlendFlags(SceneBlendType type, SceneBlendFactor& source, SceneBlendFactor& dest)
     {
         switch ( type )
         {
@@ -500,16 +500,12 @@ namespace Ogre {
             source = SBF_ONE;
             dest = SBF_ONE;
             return;
+        default:
         case SBT_REPLACE:
             source = SBF_ONE;
             dest = SBF_ZERO;
             return;
         }
-
-        // Default to SBT_REPLACE
-
-        source = SBF_ONE;
-        dest = SBF_ZERO;
     }
     //-----------------------------------------------------------------------
     void Pass::setSceneBlending(SceneBlendType sbt)
@@ -895,8 +891,7 @@ namespace Ogre {
         const auto& programUsage = getProgramUsage(type);
         if (!programUsage)
         {
-            OGRE_EXCEPT (Exception::ERR_INVALIDPARAMS,
-                "This pass does not have this program type assigned!");
+            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "This pass has no " + to_string(type) + " program");
         }
         return programUsage->getParameters();
     }
@@ -1049,27 +1044,22 @@ namespace Ogre {
     void Pass::processPendingPassUpdates(void)
     {
         {
-                    OGRE_LOCK_MUTEX(msPassGraveyardMutex);
+            OGRE_LOCK_MUTEX(msPassGraveyardMutex);
             // Delete items in the graveyard
-            PassSet::iterator i, iend;
-            iend = msPassGraveyard.end();
-            for (i = msPassGraveyard.begin(); i != iend; ++i)
+            for (auto& i : msPassGraveyard)
             {
-                OGRE_DELETE *i;
+                OGRE_DELETE i;
             }
             msPassGraveyard.clear();
         }
         PassSet tempDirtyHashList;
         {
-                    OGRE_LOCK_MUTEX(msDirtyHashListMutex);
+            OGRE_LOCK_MUTEX(msDirtyHashListMutex);
             // The dirty ones will have been removed from the groups above using the old hash now
             tempDirtyHashList.swap(msDirtyHashList);
         }
-        PassSet::iterator i, iend;
-        iend = tempDirtyHashList.end();
-        for (i = tempDirtyHashList.begin(); i != iend; ++i)
+        for (auto *p : tempDirtyHashList)
         {
-            Pass* p = *i;
             p->_recalculateHash();
         }
     }
