@@ -42,8 +42,8 @@ namespace Ogre
         public:
             TimeControllerValue(RibbonTrail* r) { mTrail = r; }
 
-            Real getValue(void) const { return 0; }// not a source 
-            void setValue(Real value) { mTrail->_timeUpdate(value); }
+            Real getValue(void) const override { return 0; }// not a source
+            void setValue(Real value) override { mTrail->_timeUpdate(value); }
         };
     }
     //-----------------------------------------------------------------------
@@ -148,6 +148,7 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void RibbonTrail::setTrailLength(Real len)
     {
+        OgreAssert(len > 0, "invalid value");
         mTrailLength = len;
         mElemLength = mTrailLength / mMaxElementsPerChain;
         mSquaredElemLength = mElemLength * mElemLength;
@@ -378,7 +379,7 @@ namespace Ogre
 
                     Element& elem = mChainElementList[seg.start + e];
                     elem.width = elem.width - (time * mDeltaWidth[s]);
-                    elem.width = std::max(Real(0.0f), elem.width);
+                    elem.width = std::max(0.0f, elem.width);
                     elem.colour = elem.colour - (mDeltaColour[s] * time);
                     elem.colour.saturate();
 
