@@ -4,26 +4,25 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org
 
-Copyright (c) 2000-2006 Torus Knot Software Ltd
-Also see acknowledgements in Readme.html
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU Lesser General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
 
-You should have received a copy of the GNU Lesser General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place - Suite 330, Boston, MA 02111-1307, USA, or go to
-http://www.gnu.org/copyleft/lesser.txt.
-
-You may alternatively use this source under the terms of a specific version of
-the OGRE Unrestricted License provided you have obtained such a license from
-Torus Knot Software Ltd.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreGLPBRenderTexture.h"
@@ -33,22 +32,12 @@ Torus Knot Software Ltd.
 #include "OgreStringConverter.h"
 #include "OgreRoot.h"
 #include "OgreGLHardwarePixelBuffer.h"
+#include "OgreGLNativeSupport.h"
 
 namespace Ogre {
-//-----------------------------------------------------------------------------  
-    GLPBuffer::GLPBuffer(PixelComponentType format, size_t width, size_t height):
-        mFormat(format),
-        mWidth(width),
-        mHeight(height)
-    {
-    }
-    GLPBuffer::~GLPBuffer()
-    {
-    }
-
 //-----------------------------------------------------------------------------  
     GLPBRenderTexture::GLPBRenderTexture(GLPBRTTManager *manager, const String &name, 
-		const GLSurfaceDesc &target, bool writeGamma, uint fsaa):
+        const GLSurfaceDesc &target, bool writeGamma, uint fsaa):
         GLRenderTexture(name, target, writeGamma, fsaa),
         mManager(manager)
     {
@@ -63,37 +52,43 @@ namespace Ogre {
     }
     void GLPBRenderTexture::getCustomAttribute(const String& name, void* pData)
     {
-        if(name=="TARGET")
+        if( name == GLRenderTexture::CustomAttributeString_TARGET )
         {
-			GLSurfaceDesc &target = *static_cast<GLSurfaceDesc*>(pData);
-			target.buffer = static_cast<GLHardwarePixelBuffer*>(mBuffer);
-			target.zoffset = mZOffset;
+            GLSurfaceDesc &target = *static_cast<GLSurfaceDesc*>(pData);
+            target.buffer = static_cast<GLHardwarePixelBufferCommon*>(mBuffer);
+            target.zoffset = mZOffset;
         }
-        else if(name=="GLCONTEXT")
+        else if (name == GLRenderTexture::CustomAttributeString_GLCONTEXT )
         {
             // Get PBuffer for our internal format
-            *static_cast<GLContext**>(pData) = mManager->getContextFor(mPBFormat, mWidth, mHeight);
+            *static_cast<GLContext**>(pData) = getContext();
         }
     }
-//-----------------------------------------------------------------------------  
-    GLPBRTTManager::GLPBRTTManager(GLSupport *support, RenderTarget *mainwindow):
-        mSupport(support),
-		mMainWindow(mainwindow),
-		mMainContext(0)
+
+    GLContext* GLPBRenderTexture::getContext() const
     {
-		mMainWindow->getCustomAttribute("GLCONTEXT", &mMainContext);
+        return mManager->getContextFor(mPBFormat, mWidth, mHeight);
+    }
+
+//-----------------------------------------------------------------------------  
+    GLPBRTTManager::GLPBRTTManager(GLNativeSupport *support, RenderTarget *mainwindow):
+        mSupport(support),
+        mMainWindow(mainwindow),
+        mMainContext(0)
+    {
+        mMainContext = dynamic_cast<GLRenderTarget*>(mMainWindow)->getContext();
     }  
     GLPBRTTManager::~GLPBRTTManager()
     {
         // Delete remaining PBuffers
-        for(size_t x=0; x<PCT_COUNT; ++x)
+        for(auto & mPBuffer : mPBuffers)
         {
-            delete mPBuffers[x].pb;
+            delete mPBuffer.pb;
         }
     }
 
     RenderTexture *GLPBRTTManager::createRenderTexture(const String &name, 
-		const GLSurfaceDesc &target, bool writeGamma, uint fsaa)
+        const GLSurfaceDesc &target, bool writeGamma, uint fsaa)
     {
         return new GLPBRenderTexture(this, name, target, writeGamma, fsaa);
     }
@@ -111,15 +106,15 @@ namespace Ogre {
 
     void GLPBRTTManager::unbind(RenderTarget *target)
     { 
-		// Copy on unbind
+        // Copy on unbind
         GLSurfaceDesc surface;
-		surface.buffer = 0;
-        target->getCustomAttribute("TARGET", &surface);
+        surface.buffer = 0;
+        target->getCustomAttribute(GLRenderTexture::CustomAttributeString_TARGET, &surface);
         if(surface.buffer)
             static_cast<GLTextureBuffer*>(surface.buffer)->copyFromFramebuffer(surface.zoffset);
     }
     
-    void GLPBRTTManager::requestPBuffer(PixelComponentType ctype, size_t width, size_t height)
+    void GLPBRTTManager::requestPBuffer(PixelComponentType ctype, uint32 width, uint32 height)
     {
         //Check size
         if(mPBuffers[ctype].pb)
@@ -150,15 +145,15 @@ namespace Ogre {
         }
     }
     
-    GLContext *GLPBRTTManager::getContextFor(PixelComponentType ctype, size_t width, size_t height)
+    GLContext *GLPBRTTManager::getContextFor(PixelComponentType ctype, uint32 width, uint32 height)
     {
         // Faster to return main context if the RTT is smaller than the window size
         // and ctype is PCT_BYTE. This must be checked every time because the window might have been resized
-		if(ctype == PCT_BYTE)
-		{
-			if(width <= mMainWindow->getWidth() && height <= mMainWindow->getHeight())
-				return mMainContext;
-		}
+        if(ctype == PCT_BYTE)
+        {
+            if(width <= mMainWindow->getWidth() && height <= mMainWindow->getHeight())
+                return mMainContext;
+        }
         assert(mPBuffers[ctype].pb);
         return mPBuffers[ctype].pb->getContext();
     }
