@@ -45,15 +45,6 @@ THE SOFTWARE.
 #include "OgreGLFBORenderTexture.h"
 #include "OgreGLStateCacheManager.h"
 
-#if OGRE_PLATFORM == OGRE_PLATFORM_WIN32
-#  define WIN32_LEAN_AND_MEAN
-#  if !defined(NOMINMAX) && defined(_MSC_VER)
-#   define NOMINMAX // required to stop windows.h messing up std::min
-#  endif
-#  include <windows.h>
-#  include <wingdi.h>
-#endif
-
 namespace Ogre {
 
 
@@ -114,12 +105,6 @@ namespace Ogre {
 
         // Adjust format if required
         mFormat = TextureManager::getSingleton().getNativeFormat(mTextureType, mFormat, mUsage);
-        
-        // Check requested number of mipmaps
-        uint32 maxMips = getMaxMipmaps();
-        mNumMipmaps = mNumRequestedMipmaps;
-        if(mNumMipmaps>maxMips)
-            mNumMipmaps = maxMips;
 
         // Check if we can do HW mipmap generation
         mMipmapsHardwareGenerated = true;
@@ -134,7 +119,7 @@ namespace Ogre {
         mRenderSystem->_getStateCacheManager()->setTexParameteri(getGLTextureTarget(), GL_TEXTURE_MAX_LEVEL,
                                                                  mNumMipmaps);
 
-        if ((mUsage & TU_AUTOMIPMAP) && mNumRequestedMipmaps)
+        if ((mUsage & TU_AUTOMIPMAP) && mNumMipmaps)
         {
             mRenderSystem->_getStateCacheManager()->setTexParameteri( getGLTextureTarget(), GL_GENERATE_MIPMAP, GL_TRUE );
         }
@@ -281,9 +266,8 @@ namespace Ogre {
 
             for(uint32 mip=0; mip<=getNumMipmaps(); mip++)
             {
-                GLHardwarePixelBuffer* buf =
-                    new GLTextureBuffer(mRenderSystem, this, face, mip, width, height, depth);
-                mSurfaceList.push_back(HardwarePixelBufferSharedPtr(buf));
+                auto buf = std::make_shared<GLTextureBuffer>(mRenderSystem, this, face, mip, width, height, depth);
+                mSurfaceList.push_back(buf);
                 
                 if (width > 1)
                     width = width / 2;
