@@ -57,7 +57,6 @@ namespace Ogre {
             X11EGLSupport(int profile);
             virtual ~X11EGLSupport();
 
-            virtual void switchMode(uint& width, uint& height, short& frequency);
             String getDisplayName(void);
 
             NativeDisplayType getNativeDisplay(void);
@@ -74,7 +73,7 @@ namespace Ogre {
                     RenderWindow* newWindow(const String& name,
                                         unsigned int width, unsigned int height,
                                         bool fullScreen,
-                                        const NameValuePairList *miscParams = 0);
+                                        const NameValuePairList *miscParams = 0) override;
 
     };
 }
