@@ -193,8 +193,8 @@ namespace Ogre {
             mWidth = width;
             mHeight = height;
 
-            for (ViewportList::iterator it = mViewportList.begin(); it != mViewportList.end(); ++it)
-                (*it).second->_updateDimensions();
+            for (auto & it : mViewportList)
+                it.second->_updateDimensions();
         }
     }
 
